Namen projekta
=================
Cilj projekta je izdelati ogrodje, ki lahko deluje 24 ur na dan in samodejno oglašuje vnaprej definirano ali dinamično vsebino, omogoča pregled poslanih sporočil in poročanje o uspešnosti preko beleženja zgodovine
poslanih sporočil.
Ker naj bi ogrodje delovalo brez prekinitev, je cilj izdelati ga na način, da bo delovalo kot demonski proces v ozadju,
brez grafičnega vmesnika.

Konfiguracijo ogrodja se bo izvedlo preko Python datoteke oz. skripte, katero se bo neposredno pognalo
v Python okolju. Ker ta način konfiguracije zahteva nekaj dela in ni najbolj enostaven, je cilj izdelati
tudi grafični vmesnik, ki bo deloval kot dodaten nivo nad samim jedrom ogrodja ter omogočal konfiguracijo in izvoz le-te
na način, da se jo bo lahko uporabilo brez grafičnega vmesnika.

Za lažji pregled dogajanja na strežniku je cilj na grafičnem vmesniku implementirati možnost oddaljenega dostopa,
ki bo omogočal direktno manipulacijo s sporočili in pregled zgodovine poslanih sporočil za določitev uspešnosti oglaševanja.



